@@ -102,6 +102,9 @@ class Storage(driver.Base):
 #            logger.error("stream_write error:%s" % e)
 #            raise e
 
+    def list_directory(self, path=None):
+        logger.info("list_directory path:%s" % path)
+        
     def stream_write(self, path, fp):
         logger.info("stream_write path:%s" % path)
         path1 = self._init_path(path)
